@@ -20,13 +20,14 @@ import Language.Haskell.HsColour.Colourise  (ColourPrefs(..))
 import qualified Language.Haskell.HsColour.TTY        as TTY
 import qualified Language.Haskell.HsColour.HTML       as HTML
 import qualified Language.Haskell.HsColour.CSS        as CSS
+import qualified Language.Haskell.HsColour.ACSS       as ACSS 
 import qualified Language.Haskell.HsColour.InlineCSS  as ICSS
 import qualified Language.Haskell.HsColour.LaTeX      as LaTeX
 import qualified Language.Haskell.HsColour.MIRC       as MIRC
-import Data.List(mapAccumL, isPrefixOf) 
+import Data.List(mapAccumL, isPrefixOf)
 import Data.Maybe
 import Language.Haskell.HsColour.Output
-import Debug.Trace
+--import Debug.Trace
 
 -- | Colourise Haskell source code with the given output format.
 hscolour :: Output      -- ^ Output format.
@@ -53,23 +54,27 @@ hscolour' :: Output      -- ^ Output format.
           -> Bool        -- ^ Whether to include anchors.
           -> String      -- ^ Haskell source code.
           -> String      -- ^ Coloured Haskell source code.
-hscolour' TTY   pref _      = TTY.hscolour   pref
-hscolour' MIRC  pref _      = MIRC.hscolour  pref
-hscolour' LaTeX pref _      = LaTeX.hscolour pref
-hscolour' HTML  pref anchor = HTML.hscolour  pref anchor
-hscolour' CSS   _    anchor = CSS.hscolour        anchor
-hscolour' ICSS  pref anchor = ICSS.hscolour  pref anchor
+hscolour' TTY       pref _      = TTY.hscolour     pref
+hscolour' (TTYg tt) pref _      = TTY.hscolourG tt pref
+hscolour' MIRC      pref _      = MIRC.hscolour    pref
+hscolour' LaTeX     pref _      = LaTeX.hscolour   pref
+hscolour' HTML      pref anchor = HTML.hscolour    pref anchor
+hscolour' CSS       _    anchor = CSS.hscolour          anchor
+hscolour' ICSS      pref anchor = ICSS.hscolour    pref anchor
+hscolour' ACSS      _    anchor = ACSS.hscolour         anchor
 
 -- | Choose the right headers\/footers, depending on the output format.
 top'n'tail :: Output           -- ^ Output format
            -> String           -- ^ Title for output
            -> (String->String) -- ^ Output transformer
 top'n'tail TTY   _     = id
+top'n'tail (TTYg _) _  = id
 top'n'tail MIRC  _     = id
 top'n'tail LaTeX title = LaTeX.top'n'tail title
 top'n'tail HTML  title = HTML.top'n'tail title
 top'n'tail CSS   title = CSS.top'n'tail  title
 top'n'tail ICSS  title = ICSS.top'n'tail title
+top'n'tail ACSS  title = CSS.top'n'tail  title
 
 -- | Separating literate files into code\/comment chunks.
 data Lit = Code {unL :: String} | Lit {unL :: String} deriving (Show)
@@ -88,6 +93,7 @@ inlines s = lines' s id
 
 
 -- | The code for classify is largely stolen from Language.Preprocessor.Unlit.
+classify ::  [String] -> [Lit]
 classify []             = []
 classify (x:xs) | "\\begin{code}"`isPrefixOf`x
                         = Lit x: allProg xs
